@@ -1,5 +1,5 @@
 package DateTime::TimeZone::Local::Win32;
-$DateTime::TimeZone::Local::Win32::VERSION = '1.95';
+$DateTime::TimeZone::Local::Win32::VERSION = '1.96';
 use 5.006;
 
 use strict;
@@ -174,6 +174,7 @@ sub EnvVars { return 'TZ' }
         'Sakhalin Standard Time'          => 'Asia/Sakhalin',
         'Samoa'                           => 'Pacific/Apia',
         'Samoa Standard Time'             => 'Pacific/Apia',
+        'Saratov Standard Time'           => 'Europe/Saratov',
         'Saudi Arabia'                    => 'Asia/Riyadh',
         'Saudi Arabia Standard Time'      => 'Asia/Riyadh',
         'SE Asia'                         => 'Asia/Bangkok',
@@ -204,6 +205,7 @@ sub EnvVars { return 'TZ' }
         'US Mountain'                     => 'America/Phoenix',
         'US Mountain Standard Time'       => 'America/Phoenix',
         'UTC'                             => 'UTC',
+        'UTC+13'                          => '+1300',
         'UTC+12'                          => '+1200',
         'UTC-02'                          => '-0200',
         'UTC-08'                          => '-0800',
@@ -314,7 +316,7 @@ DateTime::TimeZone::Local::Win32 - Determine the local system's time zone on Win
 
 =head1 VERSION
 
-version 1.95
+version 1.96
 
 =head1 SYNOPSIS
 
